@@ -6,23 +6,22 @@
 //
 
 #define SOCI_EMPTY_SOURCE
-#include "soci.h"
-#include "soci-empty.h"
+#include "soci/empty/soci-empty.h"
 
 #ifdef _MSC_VER
 #pragma warning(disable:4355)
 #endif
 
-using namespace SOCI;
-using namespace SOCI::details;
+using namespace soci;
+using namespace soci::details;
 
 
-EmptyRowIDBackEnd::EmptyRowIDBackEnd(EmptySessionBackEnd & /* session */)
+empty_rowid_backend::empty_rowid_backend(empty_session_backend & /* session */)
 {
     // ...
 }
 
-EmptyRowIDBackEnd::~EmptyRowIDBackEnd()
+empty_rowid_backend::~empty_rowid_backend()
 {
     // ...
 }
