@@ -7,24 +7,26 @@
 //
 
 #define SOCI_MYSQL_SOURCE
-#include "soci-mysql.h"
-#include <soci.h>
-#include <ciso646>
+#include "soci/mysql/soci-mysql.h"
 
 #ifdef _MSC_VER
-#pragma warning(disable:4355)
+#pragma warning(push)
+#pragma warning(disable:4355 4702)
 #endif
 
-using namespace SOCI;
-using namespace SOCI::details;
+using namespace soci;
+using namespace soci::details;
 
-
-MySQLRowIDBackEnd::MySQLRowIDBackEnd(MySQLSessionBackEnd & /* session */)
+mysql_rowid_backend::mysql_rowid_backend(
+    mysql_session_backend & /* session */)
 {
-    throw SOCIError("RowIDs are not supported.");
+    throw soci_error("RowIDs are not supported.");
 }
 
-MySQLRowIDBackEnd::~MySQLRowIDBackEnd()
+mysql_rowid_backend::~mysql_rowid_backend()
 {
-    throw SOCIError("RowIDs are not supported.");
 }
+
+#ifdef _MSC_VER
+#pragma warning(pop)
+#endif
